0.3 (09/02/2015)
----------------

Add ``tasks.get_friends_for_user``. Depends on a recent version of Celery
(>=3).


0.2 (09/02/2015)
----------------

New app.

- Client login flow works
- Canvas flow DOES NOT work
- Server side login flow DOES NOT work
